package com.yizhi.assignment.application.feign;

import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.assignment.application.vo.*;
import com.yizhi.assignment.application.vo.entity.Assignment;
import com.yizhi.assignment.application.vo.entity.AssignmentAnswerFile;
import com.yizhi.assignment.application.vo.entity.AssignmentStudent;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentAnswerCheckVO;
import com.yizhi.assignment.application.vo.apivo.AssignmentTrainingProject;
import com.yizhi.core.application.vo.DroolsVo;
import com.yizhi.util.application.domain.Response;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@FeignClient(name = "assignment", contextId = "AssignmentClient")
public interface AssignmentClient {

    /**
     * 生成作业id编号
     *
     * @return
     */
    @GetMapping("/remote/assignment/setid")
    public Long setId();

    /**
     * 新建作业保存
     *
     */
    @PostMapping("/remote/assignment/save")
    public Boolean save(@RequestBody AssignmentSaveParamVo assignmentSaveParamVo);

    /**
     * 查找作业列表
     *
     * @return
     */
    @GetMapping("/remote/assignment/list")
    public Page<AssignmentListVO> list(@RequestParam(value = "currentTime", name = "currentTime", required = false) String currentTime, @RequestBody AssignmentListVoTo assignmentListVoTo);

    /**
     * 作业删除
     *
     */
    @PostMapping("/remote/assignment/delete")
    public Boolean delete(@RequestBody AssignmentDeleteVO assignmentDelete);

    /**
     * 批量下载作业
     *
     * @param ids
     * @return
     */
    @GetMapping("/remote/assignment/download/batch")
    public List<List<AssignmentAnswerFile>> getAssignmentAnswerList(@RequestParam(name = "ids", required = true) List<Long> ids);

    /**
     * 获取学生提交的作业单个信息
     *
     */
    @PostMapping("/remote/assignment/marking/select")
    public ApiAssignmentAnswerCheckVO getAssignmentAnswer(@RequestBody AssignmentAnswerMarkingSelectVO assignmentAnswerMarkingSelect);

    /**
     * 根据assignment作业找到学员答作业列表
     *

     */
    @GetMapping(value = "/remote/assignment/answer/list")
    public Page<AssignmentReadListVO> assignmentAnswerList(@RequestParam(name = "assignmentId", required = true) Long assignmentId,
                                                           @RequestParam(name = "state", required = false) Integer state,
                                                           @RequestParam(name = "name", required = false) String name,
                                                           @RequestParam(name = "keywords", required = false) String keywords,
                                                           @RequestParam(name = "type", required = false, defaultValue = "1") Integer type,
                                                           @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                           @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize);

    /**
     * 找到作业内容
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/remote/assignment/content/find")
    public AssignmentSelectVo query(@RequestParam(name = "assignmentId", required = true) Long assignmentId);

    /**
     * 添加学员
     *
     * @param listStudent
     * @return
     */
    @PostMapping("/remote/assignment/student/add")
    public Boolean insert(@RequestBody ListStudent listStudent);

    /**
     * 添加关联学员，之前记录不删除
     *
     * @param assignmentStudents
     * @return
     */
    @PostMapping("/remote/assignment/student/insert")
    public Boolean insertStudentRelation(@RequestBody List<AssignmentStudent> assignmentStudents);

    /**
     * 已关联学员
     *
     * @param assignmentId
     */
    @GetMapping("/remote/assignment/student/relation")
    public List<AssignmentStudent> studentRelation(@RequestParam(name = "assignmentId", required = true) Long assignmentId);

    /**
     * 未关联学员
     *
     * @param assignmentId
     * @param pageNo
     * @param pageSize
     * @return
     */
    @GetMapping("/remote/assignment/student/noRelation")
    public List<Long> studentNoRelation(@RequestParam(name = "assignmentId", required = true) Long assignmentId,
                                        @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                        @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize);

    /**
     * 设置评阅人
     *
     * @param listAuditor
     * @return
     */
    @PostMapping("/remote/assignment/auditor/insert")
    public Boolean auditorInsert(@RequestBody ListAuditor listAuditor);

    /**
     * 查看已关联的评阅人
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/remote/assignment/auditor/relation")
    public List<Long> auditorRelation(@RequestParam(name = "assignmentId", required = true) Long assignmentId);

    /**
     * 作业上架/下架
     *
     */
    @PostMapping("/remote/assignment/status/update")
    public Boolean update(@RequestBody AssignmentUpAndDownVO assignmentUpAndDown);

    /**
     * 作业批阅保存
     *
     * @param assignmentAnswerContentVO
     * @return
     */
    @PostMapping("/remote/assignment/marking/save")
    public PointParamVO readSave(@RequestBody AssignmentAnswerContentVO assignmentAnswerContentVO);

    /**
     * 根据账号id查询到此学员下的作业个数
     *
     * @param accountId
     * @return
     */
    @GetMapping("/remote/assignment/select/remote/assignmentNum/byAccountId")
    public Response<Integer> selectAssignmentNumByAcountId(@RequestParam(name = "accountId", required = true) Long accountId);

    /**
     * 导出批阅结果

     */
    @PostMapping("/remote/assignment/export/suggetion/get")
    public AssignmentAnswerListExport exportSuggetionExcel(@RequestBody DownloadAnswerVO vo);

    /**
     * 批量下载作业
     *
     */
    @PostMapping("/remote/assignment/export/remote/assignment/get")
    public List<AnswersDownVO> exportAssignmentZip(@RequestBody DownloadAnswerVO vo);

    /**
     * 未提交人员名单
     *
     * @param assignmentId
     */
    @GetMapping("/remote/assignment/export/unsubmit/get")
    public AssignmentQXVO exportExcel(@RequestParam(name = "assignmentId", required = true) Long assignmentId);

    /**
     * 可见范围导出
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/remote/assignment/export/visiblRange")
    public VisibleRangeExport exportVisibleRange(@RequestParam(name = "assignmentId", required = true) Long assignmentId);

    /**
     * 培训项目挂靠作业
     *
     * @param atp
     * @return
     */
    @PostMapping("/remote/assignment/updateTrainingProject/byAssignmentId")
    public boolean updateTrainingProjectByAssignmentId(AssignmentTrainingProject atp);

    @GetMapping("/remote/assignment/by/new/server")
    public List<Map<String, Object>> getServerByCompanyIdAndIds(@RequestParam("companyId") Long companyId, @RequestParam(name = "ids", required = false) List<Long> ids);

    @GetMapping("/assignment/by/siteId/and/assignmentId/and/accountId")
    public List<Long> getListIdsBySiteIdAndAssignmentIdsAndAccountId(@RequestParam("sitId") Long siteId, @RequestParam("accountId") Long accountId, @RequestParam("ids") List<Long> ids);

    @GetMapping("/remote/assignment/delete/relation")
    public void deleteRelation(@RequestParam(name = "assignmentId", required = true) Long assignmentId);

    @PostMapping("/remote/assignment/experiencePoolList")
    public Page<Map<String, Object>> experiencePoolList(@RequestParam(value = "name", required = false) String name,
                                                        @RequestBody List<Long> ids,
                                                        @RequestParam(value = "pageNo", required = false) Integer pageNo,
                                                        @RequestParam(value = "pageSize", required = false) Integer pageSize);

    /**
     * 查询作业完成的学员
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/remote/assignment/finishAccountIds")
    public List<Long> getFinishedAccountIds(@RequestParam("assignmentId") Long assignmentId, @RequestParam("siteId") Long siteId, @RequestParam("companyId") Long companyId);

    /**
     * 查询作业分数
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/remote/assignment/getScore")
    public Integer getScore(@RequestParam("assignmentId") Long assignmentId, @RequestParam("siteId") Long siteId, @RequestParam("companyId") Long companyId, @RequestParam("accountId") Long accountId);

    /**
     * 获取单个作业主体信息
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/remote/assignment/get")
    public Assignment get(@RequestParam("assignmentId") Long assignmentId);

    @GetMapping("/remote/assignment/visibleRange")
    public List<AssignmentStudent> VisibleRange(@RequestParam("assignmentId") Long assignmentId);

    @PostMapping("/remote/assignment/verifyVedio")
    boolean verifyVedio(@RequestBody List<Long> answerFileIds);

    @PostMapping("/remote/assignment/updateVedioTranscodeUrl")
    boolean updateVedioTranscodeUrl(@RequestBody Map<String, String> map);

    @GetMapping("/remote/assignment/getPageByDrools")
    Page<DroolsVo> getPageByDrools(@RequestParam("field") String field,
                                   @RequestParam(value = "value", required = false) String value,
                                   @RequestParam("pageNo") Integer pageNo,
                                   @RequestParam("pageSize") Integer pageSize);

    /**
     * 获取用户作业列表
     * @param answerListVo
     * @return
     */
    @PostMapping(value = "/remote/assignment/manage/answer/list")
    Page<AssignmentReadListVO> manageAssignmentAnswerList(@RequestBody AnswerListVo answerListVo);
}