package com.yizhi.application.controller.remote;

import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.application.entity.Assignment;
import com.yizhi.application.entity.AssignmentPoint;
import com.yizhi.application.service.AssignmentAnswerService;
import com.yizhi.application.service.AssignmentPointService;
import com.yizhi.application.service.AssignmentService;
import com.yizhi.application.service.AssignmentStudentService;
import com.yizhi.assignment.application.vo.AssignmentCalendarVO;
import com.yizhi.system.application.vo.CalendarTaskParamVo;
import com.yizhi.assignment.application.vo.apivo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author: shengchenglong
 * @Date: 2018/3/7 13:59
 */
@Api(tags = "学员端作业接口")
@RestController
@RequestMapping("/remote/api/assignment")
public class StudentAssignmentController {


    @Autowired
    private AssignmentService assignmentService;
    @Autowired
    private AssignmentAnswerService assignmentAnswerService;
    @Autowired
    private AssignmentStudentService assignmentStudentService;
    @Autowired
    private AssignmentPointService assignmentPointService;
    
    
    
    @GetMapping("/my/answer/zip")
    public String getStudentAnswerZipByAnswerId(@RequestParam(name="assignmentId")Long assignmentId,@RequestParam("answerId")Long answerId) {
    	return assignmentAnswerService.getStudentAnswerZipByAnswerId(assignmentId, answerId);
    }

    @GetMapping("/my/list")
    @ApiOperation(value = "分页查询作业列表", notes = "分页查询作业列表")
    public Page<ApiAssignmentListResultVO> list(
            @ApiParam(name = "type", value = "类型（1：进行中，2：已完成）", required = true) @RequestParam(name = "type", defaultValue = "1") int type,
            @ApiParam(name = "pageNo", value = "要跳转的页数", required = false) @RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
            @ApiParam(name = "pageSize", value = "每页条数，默认：10", required = false) @RequestParam(name = "pageSize", defaultValue = "10") int pageSize, 
            @ApiParam(name = "accountId", value = "用户id", required = true) @RequestParam(name = "accountId") Long accountId,
            @ApiParam(name = "relationIds", value = "关联ids", required = true) @RequestParam(name = "relationIds") List<Long> relationIds,
            @ApiParam(name = "siteId", value = "站点id", required = true) @RequestParam(name = "siteId") Long siteId,
            @ApiParam(name = "companyId", value = "公司id", required = true) @RequestParam(name = "companyId") Long companyId) {
            Page<ApiAssignmentListResultVO> page = null;
            if (type == 1) {      page = assignmentService.listUnfinishedAssignment(pageNo, pageSize,accountId,relationIds,companyId,siteId);  } 
            if (type == 2) {      page = assignmentService.listFinishedAssignment(pageNo, pageSize,accountId,relationIds,companyId,siteId);    }
            return page;
    }
    
    
    @GetMapping("/my/list/search")
    @ApiOperation(value = "分页查询作业列表（按照条件查  ）", notes = "分页查询作业列表（按照条件查）")
    public Page<ApiAssignmentListResultVO> listSearch(
            @ApiParam(name = "name", value = "关键字", required = false) @RequestParam(name = "name",required=false) String name,
            @ApiParam(name = "pageNo", value = "要跳转的页数", required = false) @RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
            @ApiParam(name = "pageSize", value = "每页条数，默认：10", required = false) @RequestParam(name = "pageSize", defaultValue = "10") int pageSize,
            @ApiParam(name = "accountId", value = "用户id", required = true) @RequestParam(name = "accountId") Long accountId,
            @ApiParam(name = "relationIds", value = "关联ids", required = true) @RequestParam(name = "relationIds") List<Long> relationIds,
            @ApiParam(name = "siteId", value = "站点id", required = true) @RequestParam(name = "siteId") Long siteId) {
           return assignmentService.listAllAssignmentByName(name, pageNo, pageSize,accountId,relationIds,siteId);
    }
    
    
    @GetMapping("/my/answer/list")
    @ApiOperation(value = "答案列表", notes = "答案列表")
    public ApiAssignmentAnswerResultVo answerList(@RequestParam(name = "assignmentId") Long assignmentId,
    		                                      @RequestParam(name = "accountId") Long accountId) {
    	return assignmentAnswerService.getAnswerList(assignmentId, accountId);
    }
    
    @GetMapping("/my/getAssignment")
    @ApiOperation(value="作业详情列表",notes="作业详情列表")
    public ApiAssignmentVO getAssignment(@ApiParam(name = "assignmentId", value = "作业id", required = true) @RequestParam(name = "assignmentId") Long assignmentId,
                                         @ApiParam(name = "accountId", value = "学员账号", required = true) @RequestParam(name = "accountId") Long accountId) {
    	return assignmentService.getAssignment(assignmentId,accountId);
    }
    

    @GetMapping("/my/toAssignment")
    @ApiOperation(value = "查看某一份答案详细信息", notes = "查看某一份答案详细信息")
    public ApiAssignmentDetailsVo toAssignment(@ApiParam(name = "assignmentId", value = "作业id", required = true) @RequestParam(name = "assignmentId") Long assignmentId,
                                               @ApiParam(name = "answerId", value = "答案Id", required = true) @RequestParam(name = "answerId") Long answerId,
                                               @ApiParam(name = "accountId", value = "学员账号", required = true) @RequestParam(name = "accountId") Long accountId) {
    	 return assignmentAnswerService.toAssignment(assignmentId,answerId,accountId);
    }

    
    
    @PostMapping("/my/can/submit")
    @ApiOperation(value="判断作业是都可以提交")
    public Integer canSubmit(@RequestBody ApiAssignmentAswerVO assignmentAswerVO) {
    	return  assignmentAnswerService.canSubmitAssignmentAnswer(assignmentAswerVO);
    }
    
    
    @PostMapping("/my/submit") 
    @ApiOperation(value = "作业提交", notes = "作业提交 ")
    public Boolean submit(@RequestBody ApiAssignmentAswerVO assignmentAswerVO) {
    	return  assignmentAnswerService.submitAssignmentAnswer(assignmentAswerVO);
    }

   /* @GetMapping("/my/suggestion/get")
    @ApiOperation(value = "查看作业评阅详细信息", notes = "查看作业评阅详细信息")
    public ApiSuggestionVo getSuggesstion(@ApiParam(name = "assignmentId", value = "作业id", required = true) @RequestParam(name = "assignmentId") Long assignmentId,
    		                              @ApiParam(name = "accountId", value = "用户id", required = true) @RequestParam(name = "accountId") Long accountId) {
    	return assignmentAnswerService.getMyAnswerDetailsByAssignmentId(assignmentId,accountId);
    }*/
    
    
    
    
    @GetMapping("/my/list/search/others")
    @ApiOperation(value = "分页查询作业列表(给门户用)", notes = "分页查询作业列表（给门户用）")
    public List<ToOthersApi> listSearchOthers(
            @ApiParam(name = "name", value = "关键字", required = false) @RequestParam(name = "name",required=false) String name,
            @ApiParam(name = "pageNo", value = "要跳转的页数", required = false) @RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
            @ApiParam(name = "pageSize", value = "每页条数，默认：10", required = false) @RequestParam(name = "pageSize", defaultValue = "10") int pageSize,
            @ApiParam(name = "accountId", value = "用户id", required = true) @RequestParam(name = "accountId") Long accountId,
            @ApiParam(name = "relationIds", value = "关联ids", required = true) @RequestParam(name = "relationIds") List<Long> relationIds,
            @ApiParam(name = "siteId", value = "站点id", required = true) @RequestParam(name = "siteId") Long siteId) { 
    	return assignmentService.listSearchOthers(name, pageNo, pageSize, accountId, relationIds, siteId);
    }
    
    
    
    @GetMapping("/my/assignment/num")
    @ApiOperation(value="根据账号id查到分发给此人的作业没有提交答案的个数",notes="根据账号id查到分发给此人的作业没有提交答案的个数")
    public Integer getAssignmentNumByAccountId(@ApiParam(name="relationIds",value="关联的账号Ids")@RequestParam(name="relationIds",required=false)List<Long> relationIds,@ApiParam(name="siteId",value="站点id")@RequestParam(name="siteId",required=true)Long siteId,@ApiParam(name="accountId",value="账号id")@RequestParam(name="accountId",required=true)Long accountId) {
		return assignmentStudentService.getAssignmentNumByAccountId(relationIds,siteId,accountId);
    }
    
    
    @GetMapping("/my/toAssignmentActivity")
    @ApiOperation(value="根据id查到作业，门户用到",notes="根据id查到作业，门户用到")
    public Assignment toAssignmentActivity(@RequestParam(name = "assignmentId") Long assignmentId) {
		return assignmentService.selectById(assignmentId);
    }
    
    /*@PostMapping("/update/trainningProject")
    @ApiOperation(value="作业挂靠到培训项目",notes="作业挂靠到培训项目")
    public Boolean update(@RequestParam(name = "assignmentId") Long assignmentId) {
		return assignmentService.selectById(assignmentId);
    }*/


    @GetMapping("/training/point")
    @ApiOperation(value = "培训项目需要的培训积分")
    public Map<String, Integer> getTrainingPoint(@RequestParam(name = "ids") List<Long> ids) {
        AssignmentPoint assignmentPoint = assignmentPointService.getTrainingPoint(ids);
        Map<String, Integer> map = null;
        if (assignmentPoint != null) {
            map = new HashMap<String, Integer>(2);
            map.put("minPoint", assignmentPoint.getMinScore());
            map.put("maxPoint", assignmentPoint.getMaxScore());
        }
        return map;
    }

    @PostMapping("/getPageToCalendar")
    public Page<AssignmentCalendarVO> getPageToCalendar(@ApiParam("paramVo") @RequestBody CalendarTaskParamVo paramVo){
        Page<Assignment> page = new Page(paramVo.getPageNo(), paramVo.getPageSize());

        return assignmentService.getPageToCalendar(paramVo.getDate(),page);
    }
       
}
