package com.yizhi.application.mapper;
import java.util.Date;
import java.util.List;

import com.yizhi.application.entity.AssignmentAnswer;
import com.yizhi.assignment.application.vo.TipoffAssignmentListVO;
import com.yizhi.core.application.context.RequestContext;
import org.apache.ibatis.annotations.Param;
import com.baomidou.mybatisplus.mapper.BaseMapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.assignment.application.vo.AssignmentAnswerExport;
import com.yizhi.assignment.application.vo.AssignmentReadListVO;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentAnswerVo;
import com.yizhi.assignment.application.vo.apivo.ApiSuggestionVo;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.session.RowBounds;

/**
 * <p>
 * 学员对作业的对应关系
 Mapper 接口
 * </p>
 *
 * @author 王飞达123
 * @since 2018-03-08
 */
public interface AssignmentAnswerMapper extends BaseMapper<AssignmentAnswer> {
	
	
	
	/**
	 * 根据作业id和账号id找到最大的分数                             学员端  2018-09-07
	 * @param accountId
	 * @param assignmentId
	 * @return
	 */
	AssignmentAnswer maxGradeByAccountIdAndAssignmentId(@Param("accountId")Long accountId, @Param("assignmentId")Long assignmentId);
	
	
	
	/**                                            管理端  2018-09-07
	 * 下一份学生作业id
	 */
	Long getNextAssignmentAnswerId(@Param("createTime")Date createTime,@Param("assignmentId")Long assignmentId);
	
	
	
	
	/**
	 * 上一份学生作业id                              管理端  2018-09-07
	 */
	Long getPrevAssignmentAnswerId(@Param("createTime")Date createTime,@Param("assignmentId")Long assignmentId);

	
	/**
	 * 根据条件查询作业列表
	 * @return
	 */
	List<AssignmentReadListVO> list(@Param("admin") Integer admin, @Param("accountId")Long accountId, @Param("assignmentId")Long assignmentId,@Param("status") Integer status,@Param("type") Integer type,@Param("accountIdList") List<Long> accountIdList,Page<AssignmentReadListVO> page);

	List<AssignmentReadListVO> list(@Param("admin") Integer admin, @Param("accountId")Long accountId, @Param("assignmentId")Long assignmentId,@Param("status") Integer status,@Param("type") Integer type,@Param("accountIdList") List<Long> accountIdList);


	List<AssignmentReadListVO> getAnswerIdList(@Param("admin") Integer admin,@Param("accountId")Long accountId, @Param("assignmentId")Long assignmentId,@Param("status") Integer status,@Param("type") Integer type,@Param("accountIdList") List<Long> accountIdList);

	/**
	 * 作业总人数
	 * @param assignmentId
	 * @param status
	 * @param name
	 * @param accountIdList
	 * @param start
	 * @param end
	 * @return
	 */
	Integer listNum(@Param("assignmentId")Long assignmentId,@Param("status") Integer status,@Param("name") String name,@Param("accountIdList") List<Long> accountIdList,@Param("start") Integer start,@Param("end") Integer end);
	
	
	
	/**
	 * 批量下载学生作业结果
	 */
	List<AssignmentAnswerExport> listExport(@Param("answerIds")List<Long> ids);
	
	

	
	/**
	 * 根据答案得到答案详情
	 */
	ApiSuggestionVo getMyAnswerDetailsByAssignmentId(@Param("assignmentId")Long assignmentId,@Param("accountId")Long accountId);
	
	
	
	
	/**
	 * 分数制查出来批阅结果
	 */
	List<AssignmentAnswerExport> exportResultExcelScore(@Param("assignmentId")Long assignmentId,@Param("answerIds")List<Long> answerIds);
	
	
	/**
	 * 等级制查出来批阅结果
	 */
	List<AssignmentAnswerExport> exportResultExcelGrade(@Param("assignmentId")Long assignmentId,@Param("answerIds")List<Long> answerIds);
	
	
	
	
	
	List<ApiAssignmentAnswerVo> listApiAssignmentAnswerVo(@Param("assignmentId")Long assignmentId,@Param("accountId")Long accountId,@Param("passScore")Integer passScore);
	
	
	
	/**
	 * 导出批阅结果
	 * @param answerIds
	 * @return
	 */
	List<AssignmentAnswerExport> listAssignmentAnswerExport(@Param("answerIds")List<Long> answerIds);
	
	
	
	
	
	
	
	List<Long> getListIdsBySiteIdAndAssignmentIdsAndAccountId(@Param("siteId")Long siteId, @Param("accountId")Long accountId,@Param("ids") List<Long> ids);
	//查看是否有压缩包
	String getStudentAnswerZipByAnswerId(@Param("answerId")Long answerId);
	
	List<Long> getFinishedAccountIds(@Param("assignmentId")Long assignmentId,@Param("siteId")Long siteId,@Param("companyId")Long companyId);

	Integer getScore(@Param("assignmentId") Long assignmentId, @Param("siteId") Long siteId, @Param("companyId") Long companyId, @Param("accountId") Long accountId);

	List<TipoffAssignmentListVO> tipoffAssignmentList(@Param("assignmentName") String assignmentName,
													  @Param("context") RequestContext context, RowBounds rowBounds);

	int tipoffAssignmentListCount(@Param("assignmentName") String assignmentName,
								  @Param("context") RequestContext context);

	@Select("select count(*) from (select id " +
			"from assignment_answer " +
			"where assignment_id = #{assignmentId} and deleted = 0 " +
			"group by create_by_id) tb")
	int countCommitAccountNum(@Param("assignmentId") Long assignmentId);

    List<AssignmentAnswer> getJoinIdsByIds(@Param("siteId") Long siteId, @Param("accountId") Long accountId, @Param("ids")List<Long> ids);

    /**
     * 作业提交的次数
     * @param assignmentId
     * @param accountId
     * @param status
     * @return
     */
    Integer selectAnswerCount(@Param("assignmentId")Long assignmentId,@Param("accountId")Long accountId,@Param("status") Integer status);

}
