package com.yizhi.application.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.baomidou.mybatisplus.service.impl.ServiceImpl;
import com.yizhi.application.entity.*;
import com.yizhi.application.eum.AnswerFileTypeEnum;
import com.yizhi.application.eum.AnswerStatusEnum;
import com.yizhi.comment.application.vo.domain.PdfPagesVo;
import com.yizhi.core.application.event.EventWrapper;
import com.yizhi.comment.application.feign.PdfPagesClient;
import com.yizhi.core.application.file.constant.FileConstant;
import com.yizhi.core.application.file.util.OssUpload;
import com.yizhi.application.mapper.*;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.application.orm.util.QueryUtil;
import com.yizhi.core.application.publish.CloudEventPublisher;
import com.yizhi.application.service.*;
import com.yizhi.system.application.vo.domain.Account;
import com.yizhi.system.application.system.remote.AccountClient;
import com.yizhi.core.application.task.AbstractTaskHandler;
import com.yizhi.core.application.task.TaskExecutor;
import com.yizhi.application.util.FileReadUtil;
import com.yizhi.comment.application.vo.PdfVO;
import com.yizhi.system.application.vo.AuthorizeUsersVO;
import com.yizhi.system.application.vo.UserInfoVO;
import com.yizhi.system.application.vo.domain.Account;
import com.yizhi.util.application.constant.QueueConstant;
import com.yizhi.util.application.constant.TpActivityType;
import com.yizhi.util.application.event.AssignmentMediaTranscodingEvent;
import com.yizhi.util.application.event.TrainingProjectEvent;
import com.yizhi.util.application.zip.ZipUtil;
import com.yizhi.assignment.application.vo.*;
import com.yizhi.assignment.application.vo.apivo.*;
import com.yizhi.core.application.context.ContextHolder;
import com.yizhi.core.application.context.RequestContext;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 学员对作业的对应关系 服务实现类
 * </p>
 *
 * @author 王飞达123
 * @since 2018-03-08
 */
@Service
public class AssignmentAnswerServiceImpl extends ServiceImpl<AssignmentAnswerMapper, AssignmentAnswer> implements AssignmentAnswerService {

	private static final Logger LOG=LoggerFactory.getLogger(AssignmentAnswerServiceImpl.class);
	
	
    @Autowired
    private IdGenerator idGenerator;
    @Autowired
    private AssignmentAnswerMapper assignmentAnswerMapper;
    @Autowired
    private AssignmentAnswerFileMapper assignmentAnswerFileMapper;
    @Autowired
    private AssignmentAnswerCourseMapper assignmentAnswerContentMapper;
    @Autowired
    private AssignmentAnswerFileService assignmentAnswerFileService;
    @Autowired
    private AssignmentMapper assignmentMapper;
    @Autowired
    private AssignmentService assignmentService;
    @Autowired
    private AssignmentAnswerService assignmentAnswerService;
    @Autowired
    private AssignmentContentService assignmentContentService;
    @Autowired
    private AssignmentFileMapper assignmentFileMapper;
    @Autowired
    private AssignmentAnswerSuggestionService assignmentAnswerSuggestionService;
    @Autowired
    private AssignmentGradeMapper assignmentGradeMapper;
    @Autowired
	private TaskExecutor taskExecutor;
    @Autowired
	private CloudEventPublisher cloudEventPublisher;
    @Autowired
	private FileReadUtil fileReadUtil;
    @Autowired
    AccountClient accountClient;
    
    @Autowired
    private PdfPagesClient pdfPagesClient;
    
    @Override
    @Transactional
    public Boolean submitAssignmentAnswer(ApiAssignmentAswerVO vo) {
    	Boolean isSubmit=true;
    	Date currentDate=new Date();
    	Long assignmentId=vo.getAssignmentId();
    	Long accountId=vo.getAccountId();
    	Assignment assignment=assignmentService.selectById(assignmentId);
    	List<AssignmentAnswer> list=assignmentAnswerService.getAssignmentAnswer(assignmentId, accountId);
    	Long siteId=ContextHolder.get().getSiteId();
    	
    	/*if(list!=null) {
    		answerNum=list.size();
    	}
    	  //提交次数<指定次数
    	if(answerNum<assignment.getCount()) {
    		//不限定时间
        	if(assignment.getFinishTime()==null) {
        		isSubmit=true;
        	}
        	//限定时间  未逾期 
        	if(assignment.getFinishTime()!=null && assignment.getFinishTime().compareTo(currentDate)>0) {
        		isSubmit=true;
        	}
        	//限定时间 逾期 允许补交的
            if(assignment.getFinishTime()!=null && assignment.getFinishTime().compareTo(currentDate)<0 && assignment.getAmendable()==1) {
            	isSubmit=true;
        	}
    	}*/
    	if(isSubmit) {
    	        // 答案主体
    	        AssignmentAnswer answer = new AssignmentAnswer();
    	        answer.setId(idGenerator.generate());
    	        answer.setAccountId(vo.getAccountId());
    	        answer.setRealName(vo.getRealName());
    	        answer.setAccountName(vo.getAccountName());
    	        answer.setAssignmentId(vo.getAssignmentId());
    	        answer.setContent(vo.getContent());
    	        answer.setStatus(AnswerStatusEnum.UNCHECKED.getValue());
    	        answer.setCompanyId(vo.getCompanyId());
    	        answer.setOrgId(vo.getOrgId());
    	        answer.setSiteId(vo.getSiteId());
    	        answer.setCreateById(vo.getAccountId());
    	        answer.setCreateByName(vo.getAccountName());
    	        answer.setCreateTime(currentDate);
    	        answer.setSource(vo.getSource());
    	        assignmentAnswerMapper.insert(answer);

    	        //作业来源（1本地2做课）
    	        // 作业素材内容content      通过做课上传，素材的视频地址或者素材的富媒体的内容，  通过做课上传，不需要内容  只有几个文件
    	        if(vo.getSource()==2&&vo.getCourseId()!=null) {
    	        	 AssignmentAnswerCourse content = new AssignmentAnswerCourse();
    	             content.setId(idGenerator.generate());
    	             content.setAnswerId(answer.getId());
    	             content.setMid(vo.getCourseId());
    	             content.setCreateById(vo.getAccountId());
    	             content.setCreateByName(vo.getAccountName());
    	             content.setCreateTime(currentDate);
    	             assignmentAnswerContentMapper.insert(content);
    	        }
    	       

    	        // 答案附件（文件，可能为多个）
    	        List<ApiFileVo> fileVos = vo.getFileVos();
    	        if (vo.getSource()==1&&!CollectionUtils.isEmpty(fileVos)) {
					AssignmentMediaTranscodingEvent event = new AssignmentMediaTranscodingEvent();
					List<AssignmentMediaTranscodingEvent.FileDTO> fileDTOS = new ArrayList<>();
					List<PdfVO> pdfVOs = new ArrayList<PdfVO>();
    	            for (ApiFileVo fileVo : fileVos) {
    	                AssignmentAnswerFile file = new AssignmentAnswerFile();
    	                PdfVO pdfVO = new PdfVO();
    	                file.setId(idGenerator.generate());
    	                file.setAnwserId(answer.getId());
    	                file.setFileName(fileVo.getFileName());
    	                file.setFileUrl(fileVo.getOssUrl());
    	                file.setSuffix(fileVo.getSuffix());
    	            	String size=fileVo.getSize();
    					if(size==null) {
    						size="0M";
    					}
    	                file.setSize(size);
    	                file.setType(AnswerFileTypeEnum.ANSWER.getValue());
    	                file.setCreateById(vo.getAccountId());
    	                file.setCreateByName(vo.getAccountName());
    	                file.setCreateTime(currentDate);
    	                file.setSize(fileVo.getSize());
    	                assignmentAnswerFileMapper.insert(file);
    	                pdfVO.setBizId(file.getId());
    	                pdfVO.setBizType(TpActivityType.TYPE_ASSIGNMENT);
    	                pdfVO.setCompanyId(vo.getCompanyId());
    	                pdfVO.setSiteId(vo.getSiteId());
    	                pdfVO.setCreateById(accountId);
    	                pdfVO.setOriginalFile(file.getFileName());
    	                pdfVO.setOriginalFileUrl(file.getFileUrl());
    	                pdfVOs.add(pdfVO);
						fileDTOS.add(event.new FileDTO(file.getId(), file.getFileUrl()));
    	            }
    	            event.setType(TpActivityType.TYPE_ASSIGNMENT);
					event.setFiles(fileDTOS);
					LOG.info("媒体转码发送消息："+event.toString());
					cloudEventPublisher.publish("assignmentMediaTranscoding",
							new EventWrapper(0L, event));
					try {
						if (CollectionUtils.isNotEmpty(pdfVOs)) {
							LOG.info("pdf解析图片发送消息："+pdfVOs.toString());
							cloudEventPublisher.publish("pdfToPng",
									new EventWrapper(0L, pdfVOs));
						}
					} catch (Exception e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
						LOG.error("pdf解析图片发送消息失败：",e);
					}
				}
    	        try{
		        	taskExecutor.asynExecute(new AbstractTaskHandler() {
						@Override
						public void handle() {
							try {
								cloudEventPublisher.publish(QueueConstant.TRAINING_PROJECT_EVENT_QUEUE,
										new EventWrapper<TrainingProjectEvent>(assignmentId, 
												TrainingProjectEvent.getInstance(assignmentId, TpActivityType.TYPE_ASSIGNMENT, accountId, new Date(),siteId,null,false)));
							} catch (Exception e) {
								e.printStackTrace();
							}
						}
					});
		        }catch (Exception e){
		            LOG.error("培训项目发送消息失败：",e);
		        }
    	        return true;
    		
    	}
    	else {
    		return false;
    	}
    }



    /**
     *
     */
    @Override
    public Integer noRead(Long id,List<Long> accountIds) {
        // TODO Auto-generated method stub
        AssignmentAnswer assignmentAnswer = new AssignmentAnswer();
        assignmentAnswer.setAssignmentId(id);
        assignmentAnswer.setStatus(1);
        assignmentAnswer.setDeleted(0);
        EntityWrapper<AssignmentAnswer> wrapper = new EntityWrapper<AssignmentAnswer>(assignmentAnswer);
        wrapper.in("account_id",accountIds);
        Integer noReadCount = assignmentAnswerMapper.selectCount(wrapper);
        LOG.info("当前的数量noReadCount：{}",noReadCount);
        return noReadCount;
    }

    /**
     * 提交数量
     */
    @Override
    public Integer submitNum(Long id,List<Long> accountIds) {
        // TODO Auto-generated method stub
        AssignmentAnswer assignmentAnswer = new AssignmentAnswer();
        assignmentAnswer.setAssignmentId(id);
        assignmentAnswer.setDeleted(0);
        EntityWrapper<AssignmentAnswer> wrapper = new EntityWrapper<AssignmentAnswer>(assignmentAnswer);
        wrapper.in("account_id",accountIds);

        Integer submitNum = assignmentAnswerMapper.selectCount(wrapper);
        LOG.info("当前的数量submitNum：{}",submitNum);
        return submitNum;
    }

    @Override
    public Page<AssignmentReadListVO> assignmentAnswerList(String keywords, String name, Long assignmentId, Long accountId, Integer state, Integer type,
                                                           Integer pageNo, Integer pageSize, List<Long> accountIds) {
        RequestContext context = ContextHolder.get();
        Integer admin = context.isAdmin() ? 1 : 0 ;
        Page<AssignmentReadListVO> page = new Page<AssignmentReadListVO>(pageNo,pageSize);
        Assignment assignment=assignmentService.selectById(assignmentId);
        List<AssignmentReadListVO> list = new ArrayList<AssignmentReadListVO>();
//         根据部门查询到部门下的所有人
        List<Long> accountIdList = new ArrayList<Long>();
        List<Account> accounVOtList = new ArrayList<Account>();

        if (StringUtils.isEmpty(keywords) && StringUtils.isEmpty(name)) {
            List<Long> intersectionAccountIds = new ArrayList<>();
            if (type == 2) {
                List<AssignmentReadListVO> answerList = assignmentAnswerMapper.list(admin,accountId, assignmentId, state, type, accountIds);

                List<Long> userIds = answerList.parallelStream().map(assignmentReadListVO -> {
                    return assignmentReadListVO.getAccountId();
                }).collect(Collectors.toList());

                AuthorizeUsersVO authorizeUsersVO = new AuthorizeUsersVO();
                authorizeUsersVO.setRoleId(context.getCompanyId());
                authorizeUsersVO.setUserIds(userIds);
                Map<Long, Account> accountMap = accountClient.getAccountList(authorizeUsersVO);

                answerList = answerList.parallelStream().map(assignmentReadListVO -> {
                    Long userId = assignmentReadListVO.getAccountId();
                    assignmentReadListVO.setAccountName(accountMap.get(userId)!=null?accountMap.get(userId).getName():"");
                    assignmentReadListVO.setRealName(accountMap.get(userId)!=null?accountMap.get(userId).getFullName():"");
                    return assignmentReadListVO;
                }).collect(Collectors.toList());

                LOG.info("返回列表answerlist：{}",JSON.toJSON(answerList));
                if (!CollectionUtils.isEmpty(answerList)){
                    page.setTotal(answerList.size());
                    // 查询到答题用户id列表
//                    List<Long> ids = answerList.parallelStream().map(assignmentReadListVO -> {
//                        return assignmentReadListVO.getAccountId();
//                    }).collect(Collectors.toList());
//
//                    LOG.info("返回列表ids：{}",JSON.toJSON(ids));
                    // accountId 排序
//                    if (CollectionUtils.isNotEmpty(ids)) {
//                        accountIdList = accountClient.selectAccountIdList(ids);
                        // 列表排序
//                        setListOrder(accountIdList,answerList);


                        LOG.info("排序前：{}",JSON.toJSON(answerList));
                        answerList.sort(Comparator.comparing(AssignmentReadListVO::getAccountName,String.CASE_INSENSITIVE_ORDER).thenComparing(AssignmentReadListVO::getCreateTime, Comparator.reverseOrder()));
                        LOG.info("排序后：{}",JSON.toJSON(answerList));
//                    }
                    List<AssignmentReadListVO> pagingResultMap = getPagingResultMap(answerList, pageNo, pageSize);
                    LOG.info("返回列表：{}",JSON.toJSON(pagingResultMap));
                    list.addAll(pagingResultMap);
                    LOG.info("返回列表3：{}",JSON.toJSON(list));
                }
            } else if (type ==1 ){
                list = assignmentAnswerMapper.list(admin,accountId, assignmentId, state, type, accountIds,page);
            } else {
                list  =  Collections.emptyList();
            }

        } else {
//            accountIdList.add(0L);
            UserInfoVO userInfoVO = new UserInfoVO();
            userInfoVO.setName(name);
            userInfoVO.setFullName(name);
            userInfoVO.setOrgName(keywords);
            userInfoVO.setCompanyId(ContextHolder.get().getCompanyId());

            LOG.info("查询参数：{}",JSON.toJSON(userInfoVO));
            List<Account> userInfoVOList = accountClient.getUserInfoVOList(userInfoVO);
            LOG.info("返回的userInfoVOList结果：{}",JSON.toJSON(userInfoVOList));
            accountIdList = userInfoVOList.parallelStream().map(user -> {
                return user.getId();
            }).collect(Collectors.toList());

            if (CollectionUtils.isEmpty(accountIdList)) {
//                list = Collections.emptyList();
                return new Page<AssignmentReadListVO>();
            } else {
                LOG.info("获取用户给请求参数的用户id：{}",accountIdList);
                List<Long> intersectionAccountIds = new ArrayList<>();
                if (CollectionUtils.isNotEmpty(accountIds)) {
                    intersectionAccountIds = accountIdList.stream().filter(item -> accountIds.contains(item)).collect(Collectors.toList());
                    LOG.info("取交集后的用户ids：{}",JSON.toJSON(intersectionAccountIds));

                    if (StringUtils.isNotEmpty(keywords)&&CollectionUtils.isEmpty(intersectionAccountIds)) {
                            return new Page<AssignmentReadListVO>();
                    }
                } else {
                    intersectionAccountIds = accountIdList;
                }

                List<AssignmentReadListVO> answerList = new ArrayList<>();
                if (type == 2) {
                    answerList = assignmentAnswerMapper.list(admin,accountId, assignmentId, state, type, intersectionAccountIds);

                    if (CollectionUtils.isNotEmpty(answerList)) {

                        List<Long> userIds = answerList.parallelStream().map(assignmentReadListVO -> {
                            return assignmentReadListVO.getAccountId();
                        }).collect(Collectors.toList());

                        AuthorizeUsersVO authorizeUsersVO = new AuthorizeUsersVO();
                        authorizeUsersVO.setRoleId(context.getCompanyId());
                        authorizeUsersVO.setUserIds(userIds);
                        Map<Long, Account> accountMap = accountClient.getAccountList(authorizeUsersVO);

                        answerList = answerList.parallelStream().map(assignmentReadListVO -> {
                            Long userId = assignmentReadListVO.getAccountId();
                            assignmentReadListVO.setAccountName(accountMap.get(userId)!=null?accountMap.get(userId).getName():"");
                            assignmentReadListVO.setRealName(accountMap.get(userId)!=null?accountMap.get(userId).getFullName():"");
                            return assignmentReadListVO;
                        }).collect(Collectors.toList());
                        answerList.sort(Comparator.comparing(AssignmentReadListVO::getAccountName,String.CASE_INSENSITIVE_ORDER ).thenComparing(AssignmentReadListVO::getCreateTime, Comparator.reverseOrder()));
                    }
                } else if (type ==1){
                    answerList = assignmentAnswerMapper.list(admin,accountId, assignmentId, state, type, intersectionAccountIds);
                }
                List<AssignmentReadListVO> pagingResultMap = getPagingResultMap(answerList, pageNo, pageSize);
                LOG.info("返回分页后的结果：{}",JSON.toJSON(pagingResultMap));
                list.addAll(pagingResultMap);
                page.setTotal(answerList.size());
            }
        }

        if(CollectionUtils.isNotEmpty(list)) {
            AssignmentReadListVO assignmentReadListVO=null;
            AssignmentGrade assignmentGrade=null;
            // 排序
            for (int i = 0; i < list.size(); i++) {
                assignmentReadListVO=list.get(i);
                //已阅
                if(assignmentReadListVO!=null&&assignmentReadListVO.getStatus()==2) {
                    Integer score=assignmentReadListVO.getScore();
                    assignmentGrade=assignmentGradeMapper.getGradeByAssignmentIdAndScore(assignmentId, score);
                    if(assignmentGrade!=null) {
                        assignmentReadListVO.setGradeName(assignmentGrade.getDescription());
                    }
                }
                if(assignment!=null) {
                    assignmentReadListVO.setType(assignment.getType());
                }
                if (type == 1 ){
                    Account account = accountClient.getAccountById(assignmentReadListVO.getAccountId());
                    assignmentReadListVO.setAccountName(account!=null?account.getName():"");
                }
            }
        }
        page.setRecords(list);
        return page;
    }

    @Override
    public List<AssignmentReadListVO> getAssignmentAnswerIdList(List<Long> accountIds,String keywords,String name,Long assignmentId,Long accountId, Integer state, Integer type) {
        Assignment assignment = assignmentService.selectById(assignmentId);
        List<AssignmentReadListVO> list = new ArrayList<AssignmentReadListVO>();
        List<Long> accountIdList = new ArrayList<Long>();
        RequestContext context = ContextHolder.get();
        Integer admin = context.isAdmin() ? 1 : 0;
        if (org.apache.commons.lang3.StringUtils.isEmpty(keywords) && org.apache.commons.lang3.StringUtils.isEmpty(name)) {

            if (type == 2) {
                List<AssignmentReadListVO> answerList = assignmentAnswerMapper.getAnswerIdList(admin,accountId, assignmentId, state, type, accountIds);
                LOG.info("返回列表answerlist：{}", JSON.toJSON(answerList));
                if (!CollectionUtils.isEmpty(answerList)) {
//                    List<Long> ids = answerList.parallelStream().map(assignmentReadListVO -> {
//                        return assignmentReadListVO.getAccountId();
//                    }).collect(Collectors.toList());
//
//                    LOG.info("返回列表ids：{}", JSON.toJSON(answerList));
//                    // accountId 排序
//                    if (CollectionUtils.isNotEmpty(ids)) {
//                        accountIdList = accountClient.selectAccountIdList(ids);
//                        // 列表排序
//                        setListOrder(accountIdList, answerList);
//
//                    }

                    List<Long> userIds = answerList.parallelStream().map(assignmentReadListVO -> {
                        return assignmentReadListVO.getAccountId();
                    }).collect(Collectors.toList());

                    AuthorizeUsersVO authorizeUsersVO = new AuthorizeUsersVO();
                    authorizeUsersVO.setRoleId(context.getCompanyId());
                    authorizeUsersVO.setUserIds(userIds);
                    Map<Long, Account> accountMap = accountClient.getAccountList(authorizeUsersVO);

                    answerList = answerList.parallelStream().map(assignmentReadListVO -> {
                        Long userId = assignmentReadListVO.getAccountId();
                        assignmentReadListVO.setAccountName(accountMap.get(userId)!=null?accountMap.get(userId).getName():"");
                        assignmentReadListVO.setRealName(accountMap.get(userId)!=null?accountMap.get(userId).getFullName():"");
                        return assignmentReadListVO;
                    }).collect(Collectors.toList());


                    LOG.info("排序后的ids：{}", JSON.toJSON(answerList));
                    answerList.sort(Comparator.comparing(AssignmentReadListVO::getAccountName,String.CASE_INSENSITIVE_ORDER).thenComparing(AssignmentReadListVO::getCreateTime, Comparator.reverseOrder()));
                    list.addAll(answerList);
                    LOG.info("返回列表3：{}", JSON.toJSON(list));
                }
            } else if (type == 1) {
                list = assignmentAnswerMapper.getAnswerIdList(admin,accountId, assignmentId, state, type, accountIds);
            } else {
                list = Collections.emptyList();
            }

        } else {
            UserInfoVO userInfoVO = new UserInfoVO();
            userInfoVO.setName(name);
            userInfoVO.setFullName(name);
            userInfoVO.setOrgName(keywords);
            userInfoVO.setCompanyId(ContextHolder.get().getCompanyId());

            LOG.info("查询参数：{}", JSON.toJSON(userInfoVO));
            List<Account> userInfoVOList = accountClient.getUserInfoVOList(userInfoVO);
            LOG.info("返回的userInfoVOList结果：{}", JSON.toJSON(userInfoVOList));
            accountIdList = userInfoVOList.parallelStream().map(user -> {
                return user.getId();
            }).collect(Collectors.toList());

            if (CollectionUtils.isEmpty(accountIdList)) {
                return Collections.emptyList();
            } else {
                LOG.info("请求用户id：{}", accountIdList);
                List<Long> intersectionAccountIds = new ArrayList<>();
                if (CollectionUtils.isNotEmpty(accountIds)) {
                    intersectionAccountIds = accountIdList.stream().filter(item -> accountIds.contains(item)).collect(Collectors.toList());

                    if (StringUtils.isNotEmpty(keywords)&&CollectionUtils.isEmpty(intersectionAccountIds)) {
                        return Collections.emptyList();
                    }
                } else {
                    intersectionAccountIds = accountIdList;
                }
                if (CollectionUtils.isNotEmpty(intersectionAccountIds)) {
                    // accountId 排序
                    intersectionAccountIds = accountClient.selectAccountIdList(intersectionAccountIds);
                }


                List<AssignmentReadListVO> answerList = new ArrayList<>();
                if (type == 2) {
                    answerList = assignmentAnswerMapper.getAnswerIdList(admin,accountId, assignmentId, state, type, intersectionAccountIds);
                    if (CollectionUtils.isNotEmpty(answerList)) {

                        List<Long> userIds = answerList.parallelStream().map(assignmentReadListVO -> {
                            return assignmentReadListVO.getAccountId();
                        }).collect(Collectors.toList());

                        AuthorizeUsersVO authorizeUsersVO = new AuthorizeUsersVO();
                        authorizeUsersVO.setRoleId(context.getCompanyId());
                        authorizeUsersVO.setUserIds(userIds);
                        Map<Long, Account> accountMap = accountClient.getAccountList(authorizeUsersVO);

                        answerList = answerList.parallelStream().map(assignmentReadListVO -> {
                            Long userId = assignmentReadListVO.getAccountId();
                            assignmentReadListVO.setAccountName(accountMap.get(userId)!=null?accountMap.get(userId).getName():"");
                            assignmentReadListVO.setRealName(accountMap.get(userId)!=null?accountMap.get(userId).getFullName():"");
                            return assignmentReadListVO;
                        }).collect(Collectors.toList());

                        answerList.sort(Comparator.comparing(AssignmentReadListVO::getAccountName,String.CASE_INSENSITIVE_ORDER).thenComparing(AssignmentReadListVO::getCreateTime, Comparator.reverseOrder()));
                    }
                } else {
                    answerList = assignmentAnswerMapper.getAnswerIdList(admin,accountId, assignmentId, state, type, intersectionAccountIds);
                }
                list = answerList;
                // 列表排序
//                setListOrder(accountIdList,answerList);
                LOG.info("返回列表3：{}", JSON.toJSON(list));

            }
        }
        return list;
    }



    /**
      * @currPageNo  页面传入的页号，从一开始
      * @pageSize每页记录数
      */
    public <T> List<T> getPagingResultMap(List<T> list, Integer currPageNo, Integer pageSize) {
        Map<String, Object> retMap = new HashMap<>();

        int totalRowNum = list.size();
        int totalPageNum = (totalRowNum - 1) / pageSize + 1;

        int realPageNo = currPageNo;
        if (currPageNo > totalPageNum) {
            realPageNo = totalPageNum;
        } else if (currPageNo < 1) {
            realPageNo = 1;
        }

        int fromIdx = (realPageNo - 1) * pageSize;
        int toIdx = realPageNo * pageSize > totalRowNum ? totalRowNum : realPageNo * pageSize;

        List<T> result = list.subList(fromIdx, toIdx);

//        retMap.put("result", result);
//        retMap.put("pageNo", realPageNo);
//        retMap.put("pageRowNum", result.size());
//        retMap.put("totalRowNum", totalRowNum);
//        retMap.put("totalPageNum", totalPageNum);

        return result;
    }

//    public static void setListOrder(List<Long> orderRegulation, List<AssignmentReadListVO> targetList) {
//        Collections.sort(targetList, ((o1, o2) -> {
//            int io1 = orderRegulation.indexOf(o1.getAccountId());
//            int io2 = orderRegulation.indexOf(o2.getAccountId());
//
//            if (io1 != -1) {
//                io1 = targetList.size() - io1;
//            }
//            if (io2 != -1) {
//                io2 = targetList.size() - io2;
//            }
//
//            return io2 - io1;
//        }));
//    }
    @Override
	public Integer assignmentAnswerListNum(Long assignmentId, Integer state, String name, List<Long> accountIdList,Integer pageNo, Integer pageSize) {
		// TODO Auto-generated method stub
    	Integer start =(pageNo-1)*pageSize;
    	Integer end=pageNo*pageSize;
    	return assignmentAnswerMapper.listNum(assignmentId, state, name, accountIdList, start, end);
	}

    @Override
    public AssignmentAnswer selectAssignmentAnswerById(Long id) {
        return this.selectById(id);
    }

	@Override
	public Boolean insertTeacherToStudent(AssignmentAnswer assignmentAnswer) {
		// TODO Auto-generated method stub
		return this.updateById(assignmentAnswer);
	}

	@Override
	public List<AssignmentAnswerExport> listExport(List<Long> answerIds) {
		// TODO Auto-generated method stub
		return assignmentAnswerMapper.listExport(answerIds);
	}

	//下一份答案id
	@Override
	public Long nextAnswerId(Date createTime,Long assignmentId) {
		// TODO Auto-generated method stub
		return assignmentAnswerMapper.getNextAssignmentAnswerId(createTime,assignmentId);
	}

	//上一份答案id
	@Override
	public Long prevAnswerId(Date createTime,Long assignmentId) {
		// TODO Auto-generated method stub
		return assignmentAnswerMapper.getPrevAssignmentAnswerId(createTime,assignmentId);
	}

	@Override
	public List<AssignmentAnswer> getAssignmentAnswer(Long assignmentId, Long accountId) {
		// TODO Auto-generated method stub
		AssignmentAnswer assignmentAnswer=new AssignmentAnswer();
		assignmentAnswer.setAssignmentId(assignmentId);
		assignmentAnswer.setAccountId(accountId);
		EntityWrapper<AssignmentAnswer> wrapper=new EntityWrapper<AssignmentAnswer>(assignmentAnswer);
		wrapper.orderBy("create_time", false);
		return this.selectList(wrapper);
	}

	@Override
	public AssignmentAnswer isHaveAnswerByAccountIdAndAssignmentId(Long accountId, Long assignmentId) {
		// TODO Auto-generated method stub
		AssignmentAnswer assignmentAnswer=new AssignmentAnswer();
		assignmentAnswer.setAccountId(accountId);
		assignmentAnswer.setAssignmentId(assignmentId);
		EntityWrapper<AssignmentAnswer> wrapper=new EntityWrapper<AssignmentAnswer>(assignmentAnswer);
		return this.selectOne(wrapper);
	}

/*	@Override
	public ApiSuggestionVo getMyAnswerDetailsByAssignmentId(Long assignmentId,Long accountId) {
		// TODO Auto-generated method stub
		//1 得到的基本信息，不包括文件信息
		ApiSuggestionVo apiSuggestionVo=assignmentAnswerMapper.getMyAnswerDetailsByAssignmentId(assignmentId,accountId);
		if(apiSuggestionVo!=null) {
			//2得到老师布置得文件信息
			List<AssignmentFile> assignmentFileList=assignmentFileService.listAssignmentFile(assignmentId);
			if(!CollectionUtils.isEmpty(assignmentFileList)) {
				apiSuggestionVo.setAssignmentFileList(assignmentFileList);
			}
			
			Long answerId=apiSuggestionVo.getId();  //sql语句得到的id是答案的id 不是作业的id 和别的vo不一样
			//3得到学生提交的答案文件信息
			List<AssignmentAnswerFile> answerFileList=assignmentAnswerFileService.listGetAssignmentAnswerFile(answerId, 1);
			if(!CollectionUtils.isEmpty(answerFileList)) {
				apiSuggestionVo.setAnswerFileList(answerFileList);
			}
			//4得到老师的反馈文件
			List<AssignmentAnswerFile> backFileList=assignmentAnswerFileService.listGetAssignmentAnswerFile(answerId, 2);
			if(!CollectionUtils.isEmpty(backFileList))
				apiSuggestionVo.setBackFileList(backFileList);
		}
		return apiSuggestionVo;
	}*/



	@Override
	public AssignmentAnswerListExport exportResultExcel(Long assignmentId, List<Long> answerIds) {
		// TODO Auto-generated method stub
		//先查出来作业是等级制还是分数制
		Assignment assignment=new Assignment();
		assignment.setId(assignmentId);
		assignment=assignmentMapper.selectOne(assignment);
		AssignmentAnswerListExport assignmentAnswerListExport=new AssignmentAnswerListExport();
		assignmentAnswerListExport.setName(assignment.getName());
		assignmentAnswerListExport.setType(assignment.getType());
		
		if(!CollectionUtils.isEmpty(answerIds)) {
			List<AssignmentAnswerExport> listAssignmentAnswerExport=assignmentAnswerMapper.listAssignmentAnswerExport(answerIds);
			if(listAssignmentAnswerExport!=null&&listAssignmentAnswerExport.size()>0) {
				AssignmentGrade assignmentGrade=null;
				for (int i = 0; i < listAssignmentAnswerExport.size(); i++) {
					Integer score=listAssignmentAnswerExport.get(i).getScore();
					if(score!=null) {
						assignmentGrade=assignmentGradeMapper.getGradeByAssignmentIdAndScore(assignmentId, score);
						if(assignmentGrade!=null) {
							listAssignmentAnswerExport.get(i).setGrade(assignmentGrade.getDescription());
						}
					}
				}
			}
			assignmentAnswerListExport.setList(listAssignmentAnswerExport);
		}

		return assignmentAnswerListExport;
	}



	@Override
	public List<AnswersDownVO> getAnswerIdsDown(Long assignmentId, List<Long> answerIds) {
		// TODO Auto-generated method stub
		Assignment assignment=new Assignment();
		assignment=assignmentService.selectById(assignmentId);
		String assignmentName=assignment.getName();  //作业名字
		List<AnswersDownVO> listAnswersDownVO=new ArrayList<AnswersDownVO>();
		for (int i = 0; i < answerIds.size(); i++) {
			//用户名
			AssignmentAnswer assignmentAnswer=this.selectById(answerIds.get(i));
			AnswersDownVO answersDownVO=new AnswersDownVO();
			answersDownVO.setAccountName(assignmentAnswer.getAccountName());
			answersDownVO.setSource(assignmentAnswer.getSource());
			answersDownVO.setAssignmentName(assignmentName);
			answersDownVO.setCommitTime(assignmentAnswer.getCreateTime());
			//提交的文件
			List<AssignmentAnswerFile>  list=null;
			if(assignmentAnswer.getSource()==1) {  //只下载本地上传的
				list=assignmentAnswerFileService.listGetAssignmentAnswerFile(answerIds.get(i),1);//1代表本地上传的文件

                List<com.yizhi.assignment.application.vo.entity.AssignmentAnswerFile> assignmentAnswerFileVOList
                        = exchangeAssignmentAnswerFile(list);

				answersDownVO.setList(assignmentAnswerFileVOList);
				
				
			}
			listAnswersDownVO.add(answersDownVO);
		}
		return listAnswersDownVO;
	}

    private List<com.yizhi.assignment.application.vo.entity.AssignmentAnswerFile> exchangeAssignmentAnswerFile(List<AssignmentAnswerFile> listAssignmentAnswerFile) {
        List<com.yizhi.assignment.application.vo.entity.AssignmentAnswerFile>  assignmentAnswerFileVoList = new ArrayList<>();
        listAssignmentAnswerFile.forEach(assignmentAnswerFile -> {
            com.yizhi.assignment.application.vo.entity.AssignmentAnswerFile assignmentAnswerFileVO = new com.yizhi.assignment.application.vo.entity.AssignmentAnswerFile();
            BeanUtils.copyProperties(assignmentAnswerFile,assignmentAnswerFileVO);
            assignmentAnswerFileVoList.add(assignmentAnswerFileVO);
        });
        return assignmentAnswerFileVoList;
    }


	@Override
	public AssignmentAnswer getAssignmentAnswerByAccountAssignmentIdAndAccountId(Long assignmentId, Long accountId) {
		// TODO Auto-generated method stub
		AssignmentAnswer assignmentAnswer=new AssignmentAnswer();
		assignmentAnswer.setAccountId(accountId);
		assignmentAnswer.setAssignmentId(assignmentId);
		EntityWrapper<AssignmentAnswer> wrapper=new EntityWrapper<AssignmentAnswer>(assignmentAnswer);
		return this.selectOne(wrapper);
	}




	/**
	 * 
	 */
	@Override
	public ApiAssignmentAnswerResultVo getAnswerList(Long assignmentId, Long accountId) {
		Date curDate=new Date();
		//出参VO
		ApiAssignmentAnswerResultVo aaarv=new ApiAssignmentAnswerResultVo();
		//作业文件
		List<ApiFileVo> fileList=assignmentFileMapper.listApiFileVo(assignmentId);
		//作业信息
		Assignment assignment=assignmentMapper.selectById(assignmentId);
		//学员提交列表
		List<ApiAssignmentAnswerVo> answerResultList=null;
		if(assignment!=null) {
			answerResultList=assignmentAnswerMapper.listApiAssignmentAnswerVo(assignmentId, accountId,assignment.getPassScore());
			LOG.info("返回的学员提交作业列表：{}", JSON.toJSON(answerResultList));
			if(answerResultList!=null&&answerResultList.size()>0) {
				ApiAssignmentAnswerVo aaav=null;
				for (int i = 0; i < answerResultList.size(); i++) {
					aaav=answerResultList.get(i);
					aaav.setType(assignment.getType());
					if(aaav.getScore()!=null) {
						AssignmentGrade assignmentGrade=assignmentGradeMapper.getGradeByAssignmentIdAndScore(assignmentId, aaav.getScore());
						if(assignmentGrade!=null) {
							aaav.setGrade(assignmentGrade.getDescription());
						}	
					}
				}
			}
		}
		AssignmentContent assignmentContent=assignmentContentService.findByAssignmentId(assignmentId);
		aaarv.setId(assignmentId);
		if(assignment!=null) {
			aaarv.setAssignmentName(assignment.getName());
			aaarv.setProjectName(assignment.getTrainingProjectName());
			aaarv.setFinishTime(assignment.getFinishTime());
			aaarv.setCount(assignment.getCount());
			aaarv.setPassScore(assignment.getPassScore());
			aaarv.setAmendable(assignment.getAmendable());
			aaarv.setIsOverDue(assignment.getFinishTime().compareTo(curDate)<0?0:1);
		}
		
		if(assignmentContent!=null) {
			aaarv.setAssignmentContent(assignmentContent.getComment());
		}
		aaarv.setFileList(fileList);
		aaarv.setAnswerResultList(answerResultList);
	    aaarv.setSubmitCount(answerResultList!=null?answerResultList.size():0);
	    
	    AssignmentAnswer assignmentAnswer=assignmentAnswerMapper.maxGradeByAccountIdAndAssignmentId(accountId, assignmentId);
	    LOG.info("获取最大的分数assignmentAnswer：{}",JSON.toJSON(assignmentAnswer));
	    Integer grade=null;
	    if(assignmentAnswer!=null) {
	    	grade=assignmentAnswer.getScore();
	    }
		if(assignment!=null) {
			if(grade!=null) {
				if(grade.compareTo(assignment.getPassScore())>=0) {
					aaarv.setIsPass(1);
				}
				else{
					aaarv.setIsPass(2);
				}
			}
		}
		
		if(answerResultList!=null&&answerResultList.size()>0) {
			boolean notRead=false;
			for (int i = 0; i < answerResultList.size(); i++) {
				if(answerResultList.get(i).getStatus()==2) {   //已阅
					notRead=false;
					continue;
				}
				if(answerResultList.get(i).getStatus()==1&&answerResultList.get(i).getIsDown() == 0 ) {
					notRead=true;
					break;
				}
			}
			if(notRead) {
				aaarv.setIsScoreOrResult(2);
				aaarv.setTag("评阅中");
			}
			if(!notRead) {
				Long answerId=null;
				Integer maxGrade=null;
				AssignmentAnswerSuggestion assignmentAnswerSuggestion=null;
				if(assignmentAnswer!=null) {
					maxGrade=assignmentAnswer.getScore();
					answerId=assignmentAnswer.getId();
				}
				LOG.info("参数：{}",answerId);
                if (answerId != null) {
                    assignmentAnswerSuggestion = assignmentAnswerSuggestionService.selectSuggestionByAnswerId(answerId);

                    if (assignmentAnswerSuggestion != null) {
                        aaarv.setSuggestion(assignmentAnswerSuggestion.getSuggestion());
                    }
                    AssignmentAnswer assignmentAnswer2=assignmentAnswer.selectById(answerId);
                    aaarv.setCommitTime(assignmentAnswer2.getAuditorTime());
                }

				if(assignment!=null) {
					if(assignment.getType()==1) {
						aaarv.setIsScoreOrResult(1);
						aaarv.setTag(maxGrade!=null?maxGrade.toString():"");
					}
					if(assignment.getType()==2) {
						aaarv.setIsScoreOrResult(3);
						if(maxGrade!=null) {
							AssignmentGrade assignmentGrade=assignmentGradeMapper.getGradeByAssignmentIdAndScore(assignmentId, maxGrade);
							if(assignmentGrade!=null) {
								aaarv.setTag(assignmentGrade.getDescription());
							}
							
						}
						
					}
				}
				
			}
		}
		
		if(answerResultList==null&&assignment!=null&&assignment.getFinishTime().compareTo(curDate)<0) {
			aaarv.setIsScoreOrResult(2);
			aaarv.setTag("已逾期");
		}
		return aaarv;
	}



	@Override
	public ApiAssignmentDetailsVo toAssignment(Long assignmentId, Long answerId, Long accountId) {
		// TODO Auto-generated method stub
		//出参VO
		ApiAssignmentDetailsVo aadv=new ApiAssignmentDetailsVo();
		Assignment assignment=assignmentMapper.selectById(assignmentId);
		AssignmentContent assignmentContent=assignmentContentService.findByAssignmentId(assignmentId);
		AssignmentAnswer assignmentAnswer=assignmentAnswerService.selectById(answerId);
		List<AssignmentAnswer> listAssignmentAnswer=listAssignmentAnswerByAssignmentIdAndAccountId(assignmentId, accountId);
		List<ApiFileVo> fileList=assignmentFileMapper.listApiFileVo(assignmentId);
		List<ApiFileVo> answerFileList=assignmentAnswerFileMapper.listAssignmentAnswerFile(answerId, 1);
		answerFileList.forEach(file -> {
			if (file.isVideo() && StringUtils.isEmpty(file.getVideoSd())) {
				file.setState("处理中");
			}
			try {
                List<PdfPagesVo> pdfPageVoList = pdfPagesClient.list(file.getId(), TpActivityType.TYPE_ASSIGNMENT);
                List<PdfPages> list = new ArrayList<>();
                pdfPageVoList.forEach(pdfPageVo -> {
                    PdfPages pages = new PdfPages();
                    BeanUtils.copyProperties(pdfPageVo,pages);
                    list.add(pages);
                });
                //List<PdfPages> list = pdfPagesClient.list(file.getId(), TpActivityType.TYPE_ASSIGNMENT);
				if (CollectionUtils.isNotEmpty(list)) {
					file.setPdfPages(list);
				}
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		});
		List<ApiFileVo> backFileList=assignmentAnswerFileMapper.listAssignmentAnswerFile(answerId, 2);
		AssignmentAnswerSuggestion assignmentAnswerSuggestion=assignmentAnswerSuggestionService.selectSuggestionByAnswerId(answerId);

		if(assignment!=null) {
			aadv.setId(assignment.getId());
			aadv.setAssignmentName(assignment.getName());
			aadv.setStartTime(assignment.getCreateTime());
			aadv.setFinishTime(assignment.getFinishTime());
			aadv.setProjectName(assignment.getTrainingProjectName());
			aadv.setPassScore(assignment.getPassScore());
			aadv.setCount(assignment.getCount());
			aadv.setIsScoreAndGrade(assignment.getType());

			aadv.setAnswerAttachmentNumMax(assignment.getAnswerAttachmentNumMax());
			aadv.setAnswerAttachmentNumMin(assignment.getAnswerAttachmentNumMin());
			aadv.setAnswerCharaterNumMax(assignment.getAnswerCharaterNumMax());
			aadv.setAnswerCharaterNumMin(assignment.getAnswerCharaterNumMin());
			aadv.setShowRes(assignment.getShowRes());
			aadv.setEnableExerciseBook(assignment.getEnableExerciseBook());
			aadv.setCommitAccountNum(assignmentAnswerMapper.countCommitAccountNum(assignment.getId()));
		}
		if(assignmentContent!=null) {
			aadv.setAssignmentContent(assignmentContent.getComment());
		}
		if(assignmentAnswer!=null) {
			aadv.setStatus(assignmentAnswer.getStatus());
			aadv.setReadTime(assignmentAnswer.getAuditorTime());
			aadv.setScore(assignmentAnswer.getScore());
			AssignmentGrade	assignmentGrade=assignmentGradeMapper.getGradeByAssignmentIdAndScore(assignmentId, assignmentAnswer.getScore());
			if(assignmentGrade!=null) {
				aadv.setGrade(assignmentGrade.getDescription());
			}
			aadv.setAnswerContent(assignmentAnswer.getContent());
            aadv.setIsDown(assignmentAnswer.getIsDown());
		}
		if(assignmentAnswerSuggestion!=null) {
			aadv.setSuggestion(assignmentAnswerSuggestion.getSuggestion());
		}
		aadv.setSubmitCount(listAssignmentAnswer!=null?listAssignmentAnswer.size():0);
		aadv.setFileList(fileList);
		aadv.setAnswerFileList(answerFileList);
		aadv.setBackFileList(backFileList);
		return aadv;
	}



	@Override
	public List<AssignmentAnswer> listAssignmentAnswerByAssignmentIdAndAccountId(Long assignmentId, Long accountId) {
		// TODO Auto-generated method stub
		AssignmentAnswer assignmentAnswer=new AssignmentAnswer();
		assignmentAnswer.setAccountId(accountId);
		assignmentAnswer.setAssignmentId(assignmentId);
		assignmentAnswer.setDeleted(0);
		EntityWrapper<AssignmentAnswer> wrapper=new EntityWrapper<AssignmentAnswer>(assignmentAnswer);
		return this.selectList(wrapper);
	}

    @Override
    public Integer getAssignmentAnswerCount(Long assignmentId, Long accountId) {
        AssignmentAnswer assignmentAnswer = new AssignmentAnswer();
        assignmentAnswer.setAccountId(accountId);
        assignmentAnswer.setAssignmentId(assignmentId);
        assignmentAnswer.setDeleted(0);
        return this.selectCount(QueryUtil.condition(assignmentAnswer));
    }



	@Override
	public List<Long> getListIdsBySiteIdAndAssignmentIdsAndAccountId(Long siteId, Long accountId, List<Long> ids) {
		// TODO Auto-generated method stub
		
		return assignmentAnswerMapper.getListIdsBySiteIdAndAssignmentIdsAndAccountId(siteId, accountId, ids);
	}



	@Override
	public Integer canSubmitAssignmentAnswer(ApiAssignmentAswerVO vo) {
		// TODO Auto-generated method stub
		Integer isCanSubmit=0;//
		if(vo!=null&&vo.getAssignmentId()!=null) {
			Assignment assignment=assignmentMapper.selectById(vo.getAssignmentId());
			if(assignment!=null) {
				Long accountId=vo.getAccountId();
				Long assignmentId=vo.getAssignmentId();
				Integer submitCountNum=getAssignmentAnswerCount(assignmentId, accountId);
				if(submitCountNum==null) {
					submitCountNum=0;
				}
				
				//没有逾期 没有提交次数
				if(assignment.getFinishTime()!=null
						&&assignment.getFinishTime().compareTo(new Date())>-1
						&&submitCountNum>=assignment.getCount()) {
					return 1;
				}
				//逾期 允许补交 没有提交次数
				if(assignment.getFinishTime()!=null
						&&assignment.getFinishTime().compareTo(new Date())==-1
						&&assignment.getAmendable()==1
						&&submitCountNum>=assignment.getCount()) {
					return 1;
				}
				if(assignment.getFinishTime()!=null
						&&assignment.getFinishTime().compareTo(new Date())==-1
						&&assignment.getAmendable()==0) {
					return 2;
				}
			}
		}
		return isCanSubmit;
	}



	@Override
	public String getStudentAnswerZipByAnswerId(Long assignmentId,Long answerId) {
		// TODO Auto-generated method stub
		//先去查看有没有zip包
		String answerZipUrl=assignmentAnswerMapper.getStudentAnswerZipByAnswerId(answerId);
		if(StringUtils.isNotEmpty(answerZipUrl)) {
			return answerZipUrl;
		}
		else {
			List<ApiFileVo> listFile=assignmentAnswerFileMapper.listAssignmentAnswerFile(answerId, 1);
			if(!CollectionUtils.isEmpty(listFile)) {
				Assignment assignment=assignmentMapper.selectById(assignmentId);
				String assignmentName="";
				if(assignment!=null) {
					assignmentName=assignment.getName();
				}
				//开始进行压缩插入
				return createAnswerFileByAccountId(assignmentName,listFile,answerId);
			}
			else {
				return null;
			}
		}
	}
	
	
	
	String createAnswerFileByAccountId(String assignmentName,List<ApiFileVo> list,Long answerId) {
		String serverUrlName=FileConstant.SAVE_PATH;            //服务器的路径
		//String serverUrlName="F://home//file";
		File serverPathDir=new File(serverUrlName);
		if(!serverPathDir.exists()) {
			  serverPathDir.mkdir();
		  }
		
		String idString=idGenerator.generate().toString();
		//文件夹名字    jml作业_11002343241200
		String parentDicName=assignmentName+"_"+idString;
		//文件夹所在完整路径名字，只是名字   /home/file/jml作业_11002343241200
		String parentDicPath=serverUrlName+File.separator+parentDicName;
		//文件夹                         /home/file/11002343241200
		//文件夹创建出来
		File fileParentDicPath=new File(parentDicPath);
		fileParentDicPath.mkdir();
		for (ApiFileVo apiFileVo : list) {
			String fileUrl=apiFileVo.getOssUrl();
			String fileName=apiFileVo.getFileName();
			fileReadUtil.read(fileUrl, parentDicPath, fileName);
		}
		// /home/file/jml作业_11002343241200.zip
		String zipPath=parentDicPath+".zip";
		try {
			//将 F://home//file\jml的新作业_1150611432396677120 
			//打包成  F://home//file\jml的新作业_1150611432396677120.zip
			ZipUtil.zip(parentDicPath,zipPath);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		 String upload=null;
		 try {
			 SimpleDateFormat sdf=new SimpleDateFormat("yyyyMMddHHmmss");
			 String accountName=ContextHolder.get().getAccountName();
			 String zipName=assignmentName+"_"+accountName+"作业附件"+".zip";
			 upload=OssUpload.upload(zipPath, zipName);
			 AssignmentAnswer aa=new AssignmentAnswer();
			 aa.setId(answerId);
			 aa.setAnswerFileZip(upload);
			 assignmentAnswerMapper.updateById(aa);
		} catch (Exception e) {
			// TODO: handle exception
		}
		 
		 File pathZipFile=new File(parentDicPath);
		 File zipFile=new File(zipPath);
		 try {
			FileUtils.deleteDirectory(pathZipFile);
			FileUtils.deleteQuietly(zipFile);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return upload;
	}



	@Override
	public List<Long> getFinishedAccountIds(Long assignmentId, Long siteId, Long companyId) {
		// TODO Auto-generated method stub
		return assignmentAnswerMapper.getFinishedAccountIds(assignmentId, siteId, companyId);
	}



	@Override
	public Integer getScore(Long assignmentId, Long siteId, Long companyId, Long accountId) {
		// TODO Auto-generated method stub
		return assignmentAnswerMapper.getScore(assignmentId, siteId, companyId, accountId);
	}


}
