package com.yizhi.application.util;

import com.yizhi.application.entity.Assignment;
import com.yizhi.assignment.application.vo.MessageTaskRemindVo;
import com.yizhi.core.application.context.RequestContext;
import com.yizhi.core.application.event.EventWrapper;
import com.yizhi.core.application.publish.CloudEventPublisher;
import com.yizhi.message.application.constans.Constans;
import com.yizhi.assignment.application.vo.enums.EvenType;
import com.yizhi.message.application.enums.RelationType;
import com.yizhi.message.application.vo.MessageRemindVo;
import com.yizhi.message.application.vo.TaskVo;
import org.apache.commons.lang3.time.DateUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Component
public class AssignmentEvenSendMessage {


    @Autowired
    private CloudEventPublisher cloudEventPublisher;

    private Logger logger = LoggerFactory.getLogger(AssignmentEvenSendMessage.class);



    /**
     * 触发事件,
     *
     * @param assignment 业务参数对象
     * @param accountId
     */
    public void evenSendMessage(Assignment assignment, Long accountId, EvenType evenType, Double score) {

        if (assignment != null) {
            TaskVo taskVo = new TaskVo();
            taskVo.setTaskName(assignment.getName());
            taskVo.setTaskScore(score);
            taskVo.setTaskEndTime(assignment.getFinishTime());

            MessageRemindVo vo = new MessageRemindVo();
            vo.setTaskVo(taskVo);
            vo.setVisibleRange(assignment.getVisibleRange());
            vo.setMessageId(evenType.getKey());
            vo.setMessageType(3);
            vo.setRelationId(assignment.getId());
            vo.setRelationType(RelationType.ZY.getKey());
            vo.setSendType(1);
            //定时任务默认五分钟执行一次   这里默认6分钟
            //定时任务默认五分钟执行一次   这里默认暂时不延迟时间
            vo.setSendTime(DateUtils.addMinutes(new Date(), 0));
            if (accountId != null) {
                vo.setAccountId(accountId);
            }
            RequestContext requestContext = new RequestContext();
            requestContext.setCompanyId(assignment.getCompanyId());
            requestContext.setSiteId(assignment.getSiteId());
            requestContext.setAccountId(assignment.getCreateById());
            requestContext.setAccountName(assignment.getCreateByName());
            vo.setRequestContext(requestContext);
            try {
                //临时取消触发功能
//                cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
            } catch (Exception e) {
                e.printStackTrace();
                logger.error("发送消息失败=====================", e);
            }

        }
    }

    /**
     * 系统模板,发消息
     *
     * @param assignment 业务参数对象
     */
    public void systemSendMessage(Assignment assignment, com.yizhi.assignment.application.vo.MessageRemindVo remindVo, RequestContext context) {
        MessageRemindVo vo = new MessageRemindVo();

        //共用参数
        vo.setMessageType(2);
        vo.setRelationId(assignment.getId());
        vo.setRelationType(RelationType.ZY.getKey());
        vo.setTaskStatus(assignment.getStatus().equals(2) ? 1 : 0);
        if (context == null) {
            context = new RequestContext();
            context.setCompanyId(assignment.getCompanyId());
            context.setSiteId(assignment.getSiteId());
            context.setAccountName(assignment.getCreateByName());
            context.setAccountId(assignment.getCreateById());
        }
        vo.setRequestContext(context);

        if (vo.getMessageType() == null || vo.getRelationId() == null || vo.getRelationType() == null) {
            logger.info("messageType:"+remindVo.getMessageType()+"||"+"RelationId:"+remindVo.getRelationId()
                    +"||"+"RelationType:"+remindVo.getRelationType());
            logger.info("相关参数缺失！！");
            return;
        }

        if (remindVo.getHasDeleted()) {
            vo.setHasDeleted(remindVo.getHasDeleted());
            cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
        } else {
            if (remindVo.getTaskStatusUpdate()) {
                //1 为消息业务可发送状态  0 则不行
                vo.setTaskStatusUpdate(remindVo.getTaskStatusUpdate());
                cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
                logger.info("发送修改业务状态消息成功=====================");
                return;
            }
            if (assignment != null) {
                if (!CollectionUtils.isEmpty(remindVo.getMessageTaskRemindVos())) {

                    TaskVo taskVo = new TaskVo();
                    taskVo.setTaskName(assignment.getName());
                    taskVo.setTaskEndTime(assignment.getFinishTime());
                    vo.setMessageId(remindVo.getMessageId());
                    vo.setIsChangge(remindVo.getIsChangge());
                    List<MessageTaskRemindVo> m=  remindVo.getMessageTaskRemindVos();
                    List<com.yizhi.message.application.vo.MessageTaskRemindVo> m2=new ArrayList<>();
                    for (MessageTaskRemindVo m1:m
                    ) {
                        com.yizhi.message.application.vo.MessageTaskRemindVo mx=new com.yizhi.message.application.vo.MessageTaskRemindVo();
                        BeanUtils.copyProperties(m1,mx);
                        m2.add(mx);
                    }
                    vo.setMessageTaskRemindVos(m2);
                    vo.setSendType(remindVo.getSendType());
                    vo.setVisibleRange(assignment.getVisibleRange());
                    vo.setTaskVo(taskVo);
                    if (vo.getMessageId() == null || vo.getSendType() == null || vo.getVisibleRange() == null) {
                        logger.info("messageID:"+remindVo.getMessageId()+"||"+"sendType:"+remindVo.getSendType()
                                +"||"+"VisibleRange:"+remindVo.getVisibleRange());
                        logger.info("相关参数缺失！！!!!");
                        return;
                    }
                    try {
                        cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
                        logger.info("发送消息成功=====================");
                    } catch (Exception e) {
                        e.printStackTrace();
                        logger.error("发送消息失败=====================", e);
                    }
                }
            }
        }
    }
}
